clc
clear
close all

% 05-11-2019

% COP 
% Head rows = 5 rows
% Columns = Frame,Sub Frame,Fx,Fy,Fz,Mx,My,Mz,Cx,Cy,Cz,Pin 1,Pin 2,Pin 3,Pin 4,Pin 5,Pin 6,Fx,Fy,Fz,Mx,My,Mz,Cx,Cy,Cz,1
% Columns = Time,Time,N,N,N,N.mm,N.mm,N.mm,mm,mm,mm,V,V,V,V,V,V,N,N,N,N.mm,N.mm,N.mm,mm,mm,mm,V

% x = lenghtaxis (+ values from PC to glass door) 
% y = transverse axis (+ values from windows to cupboards) 


%% Read data -- Just prepare COP-signals

    for subj = 1:38
        for trial = [1,2,3]    
      
                %% COP data (Raw data)
                freq = 3000;   
                filename = ['s',num2str(subj),'t',num2str(trial),'.csv'];
                data = importdata(filename, ',', 5);   % first five rows were cut off.
                
                % --> cut the head row for 5 rows, cut columns number 1, the first 5 seconds, and analyse middle 25 seconds
                time_0 = data.data(15001:90000,1);    % Time data is all the data of column 1
                fx_0 = data.data(15001:90000,3);      % _v is used to indicate these are voltage data
                fy_0 = data.data(15001:90000,4);      % fx = ML direction
                fz_0 = data.data(15001:90000,5);      % fy = AP direction
                Mx_0 = data.data(15001:90000,6);
                My_0 = data.data(15001:90000,7);
                Mz_0 = data.data(15001:90000,8);
                                
                % Low pass filter
                [b,a] = butter(3,10/3000,'low');   % 1250 is frequency, 4th, and 5 cut-off   
                fx_v = filtfilt(b,a,fx_0);  % _v is used to indicate these are voltage data
                fy_v = filtfilt(b,a,fy_0); 
                fz_v = filtfilt(b,a,fz_0); 
                Mx_v = filtfilt(b,a,Mx_0); 
                My_v = filtfilt(b,a,My_0); 
                Mz_v = filtfilt(b,a,Mz_0); 
                
                % Downsampling
                time_1 = time_0(1:12:end);    % Time data is all the data of column 1
                fx_1 = fx_v(1:12:end);      % _v is used to indicate these are voltage data
                fy_1 = fy_v(1:12:end);      % fx = ML direction
                fz_1 = fz_v(1:12:end);      % fy = AP direction
                Mx_1 = Mx_v(1:12:end);
                My_1 = My_v(1:12:end);
                Mz_1 = Mz_v(1:12:end);
                
                Fx_sf = 30; % N
                Fy_sf = 30; % N
                Fz_sf = 8; % N
                Mx_sf = 1.75;  % N.mm
                My_sf = 1.75;  % N.mm
                Mz_sf = 3.5;  % N.mm
                
                % Convert data to N and N-m using the scaling factor
                t = time_1;  % seconds
                fx = fx_1.*Fx_sf;  % N
                fy = fy_1.*Fy_sf;  % N
                fz = fz_1.*Fz_sf;  % N
                Mx = Mx_1.*Mx_sf;  % N-m
                My = My_1.*My_sf;  % N-m
                Mz = Mz_1.*Mz_sf;  % N-m
                
                % COP data from Revision of posturography (Marcos 20)
%                 yp = -My./fz;  % millimeter
%                 xp = Mx./fz;   % To devide vectors element by element, i need a ./
                h = 0; % h = the height of the base of support above the force plate
                yp = (-h*fx-My)./fz;  % millimeter
                xp = (-h*fy+Mx)./fz;   % To devide vectors element by element, i need a ./
                
                CPap = yp;
                CPml = xp;
                
                 %% Normalization, used code from de Oliveira, 2017: Statokinesigram normalization method
                [CPap_norm,CPml_norm] = statoknorm(CPap,CPml);     
                   
                SDap(subj,trial) = std(CPap_norm);
                SDml(subj,trial) = std(CPml_norm);

                AdCPap(subj,trial) = max(CPap_norm) - min(CPap_norm);
                AdCPml(subj,trial) = max(CPml_norm) - min(CPml_norm);
                
                MVap(subj,trial) = sum(abs(diff(CPap_norm)))*freq/length(CPap_norm);
                MVml(subj,trial) = sum(abs(diff(CPml_norm)))*freq/length(CPml_norm);

        end
    end

    
    
    
    
    
    
    
    
    
    
    
    
    
        